Utilities and re-exports
Re-exports
pub use tokio_runtime::RUNTIME;pub use mwc_api;pub use mwc_chain;pub use mwc_core;pub use mwc_keychain;pub use mwc_p2p;pub use mwc_store;pub use mwc_util;
Structs
- Onion
V3Address - Struct to hold an onion V3 address, represented internally as a raw ed25519 public key
- RUNTIME
- Note: RUNTIME can be used in multiple crates, that is why it is declared in utils.
Global Tokio runtime.
Needs a
MutexbecauseRuntime::block_onrequires mutable access. Tokio v0.3 requires immutable self, but we are waiting on upstream updates before we can upgrade. See: https://github.com/seanmonstar/reqwest/pull/1076
Enums
- Onion
V3Address Error - OnionV3 Address Errors